#!/bin/sh
#
# Component: hl7
#
# Description:
#  Creates HL7 Report message(s) for a study.
#
# Usage:
#  createMessage.sh [-h] [-V] [-D] -S <study> -f <reportFile> -m <message type> [-e <event>]
#                   [-d <device>] [-i <message ID>] [-s | -o <message file>]
#    -h                : prints help
#    -V                : print verbose messages
#    -D                : print debug messages
#    -s                : start message sending task
#    -S <study>        : create message for this study
#    -f <reportFile>   : create message from this report file
#    -m <message type> : type of the message should be sent (REPORT)
#    -d <device>       : device the message was originated from (default: LOCAL)" << endl
#    -o <message file> : write message to this file (instead of default: $HL7_MESSAGES/<message ID>)
#    -i <message ID>   : unique ID for the message (max 20 char) (default: generate one)
#    -e <event>        : Event ID - needed for event specific messages
#  !!!! -s and -o options are could not be used together
#
# Since createORUMessage.sh simply pass all parameters to createORUMessage, the usage info
# above is informative. Check createMessage for actual usage information.
#
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#
#

. $HOME/etc/setenv.sh

# TODO:
#   We should check if there is any HL7 device configured in the dotcom!!!

# In some cases we miss language settings and if we don't
# have correct language settings, then createMessage hangs

if [ -z "$LANG" ] ; then
  LANG=en_US
  SUPPORTED=en_US:en

  export LANG SUPPORTED
fi


$HL7_HOME/bin/createORUMessage $@

