#!/bin/sh
#
# Component: hl7
#   Shell task for sending HL7 messages to HIS/RIS devices.
#

. $HOME/etc/setenv.sh

# if setstudyprp.sh is called directly:
# run as a task instead
if [ `basename $0` = "sendMessageTask.sh" ] ; then
	DirectCall="true"
	export DirectCall

	$TASKD_HOME/runshellcmd.sh -R -r 0 $0 "$@"
	exit $?
fi


# In some cases we miss language settings and if we don't
# have correct language settings, then createMessage hangs

if [ -z "$LANG" ] ; then
  LANG=en_US
  SUPPORTED=en_US:en

  export LANG SUPPORTED
fi

PEER_DEVICE=""
PRGARGS=""
errMsg=""
while getopts 'hVDad:e:f:c:t:' OPT; do
	case $OPT in
	h) PRGARGS="$PRGARGS -h" ;;
	V) PRGARGS="$PRGARGS -V" ;;
	D) PRGARGS="$PRGARGS -D" ;;
	a) PRGARGS="$PRGARGS -a" ;;
	d) PEER_DEVICE="$OPTARG" ; PRGARGS="$PRGARGS -d \"$OPTARG\"" ;;
	e) PRGARGS="$PRGARGS -e \"$OPTARG\"" ;;
	f) PRGARGS="$PRGARGS -f \"$OPTARG\"" ;;
	c) PRGARGS="$PRGARGS -c \"$OPTARG\"" ;;
	t) PRGARGS="$PRGARGS -t \"$OPTARG\"" ;;
	*) errMsg="Invalid_Parameter:$OPT" ;;
	esac
done

# include nettask.shi for checking if the device is temporary down
. $TASKD_HOME/nettask.shi

# override getPeer_() of nettask.shi
function getPeer_()
{
	echo "$PEER_DEVICE"
}


# override run_ method
function run_()
{
	[ -n "$errMsg" ] && return 125

	# Check if the target device is temporarily down and return
	checkPeer_
	if [ $? -ne 0 ] ; then
		return 1
	fi

	HL7_OPTIONS=""
	[ -f "$RUN/hl7.options" ] && . $RUN/hl7.options
	
	if [ "$DirectCall" = "true" -o -z "$HL7_OPTIONS" ] ; then
		eval $HL7_HOME/bin/sendMessage -R $RETRY_NUM $PRGARGS
		res=$?
	else
		echo "$(date +'%Y/%m/%d %H:%M:%S (%Z)') START sendMessage[$$]" > $TMP/hl7out.$$
		eval $HL7_HOME/bin/sendMessage -R $RETRY_NUM $HL7_OPTIONS $PRGARGS >>$TMP/hl7out.$$ 2>&1
		res=$?
		echo "$(date +'%Y/%m/%d %H:%M:%S (%Z)') END sendMessage[$$]" >> $TMP/hl7out.$$
		cat $TMP/hl7out.$$ >> $LOG/hl7outgoing.log
		rm $TMP/hl7out.$$
	fi
	
	return $res
}


# override print_
function print_()
{
	eval $HL7_HOME/bin/sendMessage -P $PRGARGS
}

#
# default get resources 
#
function get_resources_()
{
	echo "System.NET.Devices:$PEER_DEVICE"
}


#
# default get display name (for subjob)
#
function get_display_name_()
{
	echo "Sends HL7 message to RIS connected to local server"
}

#
# get property
#
function get_property_()
{
	if [ "$PROPERTY" = "1PPE" -a -n "$PEER_DEVICE" ] ; then
		echo "$PEER_DEVICE" 
	else
		get_def_property_
	fi
}

# override cleanup_
function cleanup_()
{
	eval $HL7_HOME/bin/sendMessage -C $PRGARGS
}

