#!/bin/sh
#
# Sends HL7 report message from the content of SR file to the given device.
#
# Use only on the device connected to the RIS.
#
# Usage:
#    sendReport.sh -s <study>  {-f <filename> | -u <SR uid>} -d <device> [-e <event>]
#
#        -s <study>      : Study Instance UID
#        -f <filename>   : SRt file name
#        -u <SR uid>     : SR Instance UID
#        -d <device>     : Device ID of the HL7 device the message will be sent
#        -e <event>      : message event (currently omitted)
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#

. $HOME/etc/setenv.sh

# LOGGER="/usr/bin/logger"
# TAG="sendReport[$$]"

#
# Usage
#
usage_()
{
	if [ -n "$1" ] ; then
		echo $1
	fi
	echo
	echo "Usage:"
	echo "   sendReport.sh -s <study>  {-f <filename> | -u <SR uid>} -d <device> [-e <event>]"
	echo
	echo "       -s <study>      : Study Instance UID"
	echo "       -f <filename>   : SRt file name"
	echo "       -u <SR uid>     : SR Instance UID"
	echo "       -d <device>     : Device ID of the HL7 device the message will be sent"
	echo "       -e <event>      : message event (currently omitted)"
	echo
	echo "Use only on the device connected to the RIS."
} # usage



ERRMSG=""
study=""
sruid=""
filename=""
event="HL7_REPORT_APPROVED"
device=""

while getopts 'f:s:u:d:e:' OPT; do
	case $OPT in
		f) filename="$OPTARG" ;;
		e) event="$OPTARG" ;;
		d) device="$OPTARG" ;;
		s) study="$OPTARG" ;;
		u) sruid="$OPTARG" ;;
		*) ERRMSG="Invalid_Parameter:$OPT" ;;
	esac
done

[ -z "$study" ] && ERRMSG="Missing Parameter: '-s <study uid>'"
[ -z "$device" ] && ERRMSG="Missing Parameter: '-d <device>'"
[ -z "$filename" -a -z "$sruid" ] && ERRMSG="Missing Parameter: '-f <filename>' or '-u <sr uid>'"
[ -n "$filename" -a -n "$sruid" ] && ERRMSG="Exactly one of '-f' or -u' should be specified"

if [ -n "$ERRMSG" ] ; then
	usage_ "$ERRMSG" >&2
	exit 1
fi

SRNAME=""
if [ -n "$filename" ] ; then
	[ -f "$DICOM_DATA/$study/$filename" ] && SRNAME="$DICOM_DATA/$study/$filename"
elif [ -n "$sruid" ] ; then
	F=`ls $DICOM_DATA/$study/SR*${sruid} 2>/dev/null`
	[ -n "$F" -a -f "$F" ] && SRNAME="$F"
fi

if [ -z "$SRNAME" ] ; then
	echo "The SRt file does not exist [${study}/${filename}${sruid}]" >&2
	exit 1
fi

msgfile="$TMP/hl7report.$$"

echo "$HL7_HOME/bin/createORUMessage.sh -V -D -f \"$SRNAME\" -m \"REPORT\" -d LOCAL -e \"$event\" -o \"$msgfile\""

$HL7_HOME/bin/createORUMessage.sh -V -D -f "$SRNAME" -m "REPORT" -d LOCAL -e "$event" -o "$msgfile"
if [ $? -ne 0 ] ; then
	echo "Error creating HL7 report message from $SRNAME" >&2
	exit 1
fi

$TASKD_HOME/createtaskfileapp -p "HL7_LOCAL_SEND_MESSAGE" -d "DELTA_HL7_LOCAL_SEND_MESSAGE_REPORT" -t "sh" -c "${HL7_HOME}/bin/sendMessageTask.sh -f \"${msgfile}\" -d \"${device}\" -t MSG"

echo "starting task $TASKNAME sending ${msgfile}"

exit 0
